==> arknights_mower-1.0.18-py3-none-any.whl: arknights_mower/data/recog.py <==
from ..utils.scene import Scene

get_scene_test = [
    ['index_nav', Scene.INDEX],
    ['12cadpa', Scene.LOGIN_START],
    ['agent_token', Scene.RECRUIT_AGENT],
    ['agent_unlock', Scene.SHOP_CREDIT],
    ['biography', Scene.TERMINAL_BIOGRAPHY],
    ['collection', Scene.TERMINAL_COLLECTION],
    ['credit_visiting', Scene.FRIEND_VISITING],
    ['double_confirm', Scene.DOUBLE_CONFIRM],
    ['episode', Scene.TERMINAL_EPISODE],
    ['friend_list', Scene.FRIEND_LIST_OFF],
    ['friend_list_on', Scene.FRIEND_LIST_ON],
    ['infra_overview', Scene.INFRA_MAIN],
    ['infra_todo', Scene.INFRA_TODOLIST],
    ['loading', Scene.LOADING],
    ['loading2', Scene.LOADING],
    ['loading3', Scene.LOADING],
    ['loading4', Scene.LOADING],
    ['loading6', Scene.LOADING],
    ['login_account', Scene.LOGIN_MAIN],
    ['login_awake', Scene.LOGIN_QUICKLY],
    ['login_captcha', Scene.LOGIN_INPUT],
    ['login_iknow', Scene.LOGIN_ANNOUNCE],
    ['login_loading', Scene.LOGIN_LOADING],
    ['main_theme', Scene.TERMINAL_MAIN_THEME],
    ['materiel_ico', Scene.MATERIEL],
    ['mission_daily_on', Scene.MISSION_DAILY],
    ['mission_weekly_on', Scene.MISSION_WEEKLY],
    ['nav_index', Scene.NAVIGATION_BAR],
    ['ope_agency_going', Scene.OPERATOR_ONGOING],
    ['ope_elimi_finished', Scene.OPERATOR_ELIMINATE_FINISH],
    ['ope_eliminate', Scene.OPERATOR_ELIMINATE],
    ['ope_finish', Scene.OPERATOR_FINISH],
    ['ope_firstdrop', Scene.OPERATOR_DROP],
    ['ope_giveup', Scene.OPERATOR_GIVEUP],
    ['ope_plan', Scene.OPERATOR_BEFORE],
    ['ope_recover_originite_on', Scene.OPERATOR_RECOVER_ORIGINITE],
    ['ope_recover_potion_on', Scene.OPERATOR_RECOVER_POTION],
    ['ope_select_start', Scene.OPERATOR_SELECT],
    ['open_recruitment', Scene.RECRUIT_MAIN],
    ['recruiting_instructions', Scene.RECRUIT_TAGS],
    ['shop_cart', Scene.SHOP_CREDIT_CONFIRM],
    ['shop_credit_2', Scene.SHOP_OTHERS],
    ['skip', Scene.SKIP],
    ['terminal_pre', Scene.TERMINAL_MAIN],
    ['upgrade', Scene.UPGRADE],
]

recog_test = [
    ['nav_button', [
        Scene.INFRA_MAIN,
        Scene.INFRA_TODOLIST,
        Scene.FRIEND_LIST_OFF,
        Scene.FRIEND_LIST_ON,
        Scene.FRIEND_VISITING,
        Scene.MISSION_DAILY,
        Scene.MISSION_WEEKLY,
        Scene.TERMINAL_MAIN,
        Scene.TERMINAL_MAIN_THEME,
        Scene.TERMINAL_EPISODE,
        Scene.TERMINAL_BIOGRAPHY,
        Scene.TERMINAL_COLLECTION,
        Scene.OPERATOR_BEFORE,
        Scene.OPERATOR_SELECT,
        Scene.SHOP_OTHERS,
        Scene.SHOP_CREDIT,
        Scene.SHOP_CREDIT_CONFIRM,
        Scene.RECRUIT_MAIN,
        Scene.RECRUIT_TAGS,
        Scene.OPERATOR_ELIMINATE,
    ]],
    ['terminal_small', Scene.TERMINAL_MAIN],
    ['career_needs', Scene.RECRUIT_TAGS],
    ['available_level', Scene.RECRUIT_TAGS],
    ['recruit_budget', Scene.RECRUIT_TAGS],
    ['login_button', Scene.LOGIN_INPUT],
    ['mission_weekly', Scene.MISSION_DAILY],
    ['mission_daily', Scene.MISSION_WEEKLY],
    ['nav_shop', Scene.NAVIGATION_BAR],
    ['nav_terminal', Scene.NAVIGATION_BAR],
    ['nav_mission', Scene.NAVIGATION_BAR],
    ['nav_social', Scene.NAVIGATION_BAR],
    ['nav_infrastructure', Scene.NAVIGATION_BAR],
    ['nav_recruit', Scene.NAVIGATION_BAR],
    ['nav_terminal', Scene.NAVIGATION_BAR],
    ['index_mission', Scene.INDEX],
    ['index_friend', Scene.INDEX],
    ['index_infrastructure', Scene.INDEX],
    ['index_recruit', Scene.INDEX],
    ['index_shop', Scene.INDEX],
    ['index_terminal', Scene.INDEX],
    ['enter', [Scene.TERMINAL_EPISODE, Scene.TERMINAL_BIOGRAPHY]],
]

==> arknights_mower-1.0.20-py3-none-any.whl: arknights_mower/data/recog.py <==
from ..utils.scene import Scene

scene_notest = [
    Scene.LOADING,
    Scene.ANNOUNCEMENT,
    Scene.LOGIN_LOADING,
    Scene.NAVIGATION_BAR,
]

scene_test = [
    ['index_nav', Scene.INDEX],
    ['12cadpa', Scene.LOGIN_START],
    ['agent_token', Scene.RECRUIT_AGENT],
    ['agent_unlock', Scene.SHOP_CREDIT],
    ['biography', Scene.TERMINAL_BIOGRAPHY],
    ['collection', Scene.TERMINAL_COLLECTION],
    ['credit_visiting', Scene.FRIEND_VISITING],
    ['double_confirm', Scene.DOUBLE_CONFIRM],
    ['episode', Scene.TERMINAL_EPISODE],
    ['friend_list', Scene.FRIEND_LIST_OFF],
    ['friend_list_on', Scene.FRIEND_LIST_ON],
    ['infra_overview', Scene.INFRA_MAIN],
    ['infra_todo', Scene.INFRA_TODOLIST],
    ['loading', Scene.LOADING],
    ['loading2', Scene.LOADING],
    ['loading3', Scene.LOADING],
    ['loading4', Scene.LOADING],
    # ['loading6', Scene.LOADING],
    ['login_account', Scene.LOGIN_MAIN],
    ['login_awake', Scene.LOGIN_QUICKLY],
    ['login_captcha', Scene.LOGIN_INPUT],
    ['login_iknow', Scene.LOGIN_ANNOUNCE],
    # ['login_loading', Scene.LOGIN_LOADING],
    ['main_theme', Scene.TERMINAL_MAIN_THEME],
    ['materiel_ico', Scene.MATERIEL],
    ['mission_daily_on', Scene.MISSION_DAILY],
    ['mission_weekly_on', Scene.MISSION_WEEKLY],
    # ['nav_index', Scene.NAVIGATION_BAR],
    ['ope_agency_going', Scene.OPERATOR_ONGOING],
    ['ope_elimi_finished', Scene.OPERATOR_ELIMINATE_FINISH],
    ['ope_eliminate', Scene.OPERATOR_ELIMINATE],
    ['ope_finish', Scene.OPERATOR_FINISH],
    ['ope_firstdrop', Scene.OPERATOR_DROP],
    ['ope_giveup', Scene.OPERATOR_GIVEUP],
    ['ope_plan', Scene.OPERATOR_BEFORE],
    ['ope_recover_originite_on', Scene.OPERATOR_RECOVER_ORIGINITE],
    ['ope_recover_potion_on', Scene.OPERATOR_RECOVER_POTION],
    ['ope_select_start', Scene.OPERATOR_SELECT],
    ['open_recruitment', Scene.RECRUIT_MAIN],
    ['recruiting_instructions', Scene.RECRUIT_TAGS],
    ['shop_cart', Scene.SHOP_CREDIT_CONFIRM],
    ['shop_credit_2', Scene.SHOP_OTHERS],
    ['skip', Scene.SKIP],
    ['terminal_pre', Scene.TERMINAL_MAIN],
    ['upgrade', Scene.UPGRADE],
]

recog_test = [
    ['nav_button', [
        Scene.INFRA_MAIN,
        Scene.INFRA_TODOLIST,
        Scene.FRIEND_LIST_OFF,
        Scene.FRIEND_LIST_ON,
        Scene.FRIEND_VISITING,
        Scene.MISSION_DAILY,
        Scene.MISSION_WEEKLY,
        Scene.TERMINAL_MAIN,
        Scene.TERMINAL_MAIN_THEME,
        Scene.TERMINAL_EPISODE,
        Scene.TERMINAL_BIOGRAPHY,
        Scene.TERMINAL_COLLECTION,
        Scene.OPERATOR_BEFORE,
        Scene.OPERATOR_SELECT,
        Scene.SHOP_OTHERS,
        Scene.SHOP_CREDIT,
        Scene.SHOP_CREDIT_CONFIRM,
        Scene.RECRUIT_MAIN,
        Scene.RECRUIT_TAGS,
        Scene.OPERATOR_ELIMINATE,
    ]],
    # ['terminal_small', Scene.TERMINAL_MAIN],
    ['career_needs', Scene.RECRUIT_TAGS],
    ['available_level', Scene.RECRUIT_TAGS],
    ['recruit_budget', Scene.RECRUIT_TAGS],
    ['login_button', Scene.LOGIN_INPUT],
    ['mission_weekly', Scene.MISSION_DAILY],
    ['mission_daily', Scene.MISSION_WEEKLY],
    ['nav_index', Scene.NAVIGATION_BAR],
    ['nav_shop', Scene.NAVIGATION_BAR],
    ['nav_terminal', Scene.NAVIGATION_BAR],
    ['nav_mission', Scene.NAVIGATION_BAR],
    ['nav_social', Scene.NAVIGATION_BAR],
    ['nav_infrastructure', Scene.NAVIGATION_BAR],
    ['nav_recruit', Scene.NAVIGATION_BAR],
    ['nav_terminal', Scene.NAVIGATION_BAR],
    ['index_mission', Scene.INDEX],
    ['index_friend', Scene.INDEX],
    ['index_infrastructure', Scene.INDEX],
    ['index_recruit', Scene.INDEX],
    ['index_shop', Scene.INDEX],
    ['index_terminal', Scene.INDEX],
    ['enter', [Scene.TERMINAL_EPISODE, Scene.TERMINAL_BIOGRAPHY]],
]
